"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.flattenObjectKeys = exports.get = void 0;

const get = (obj, path, def) => {
  const stringToPath = pathValue => {
    if (typeof pathValue !== 'string') {
      return pathValue;
    }

    const output = [];
    pathValue.split('.').forEach(item => {
      item.split(/\[([^}]+)\]/g).forEach(key => {
        if (key.length > 0) {
          output.push(key);
        }
      });
    });
    return output;
  };

  const findPath = stringToPath(path);
  let current = obj;

  for (let i = 0; i < findPath.length; i++) {
    if (!current[findPath[i]]) {
      return def;
    }

    current = current[findPath[i]];
  }

  return current;
};

exports.get = get;

const flattenObjectKeys = (obj, prefix = '', flatObjectProps = []) => {
  Object.keys(obj).reduce((acc, k) => {
    const pre = prefix.length ? `${prefix}.` : '';

    if (typeof obj[k] === 'object') {
      Object.assign(acc, flattenObjectKeys(obj[k], pre + k, flatObjectProps));
    } else {
      flatObjectProps.push(pre + k);
    }

    return acc;
  }, {});
  return flatObjectProps;
};

exports.flattenObjectKeys = flattenObjectKeys;